@@ -7,9 +7,7 @@ pub mod v2 {
     //!
     //! [spec]: https://spec.matrix.org/v1.2/identity-service-api/#get_matrixidentityv2pubkeykeyid
 
-    use ruma_api::ruma_api;
-    use ruma_identifiers::ServerSigningKeyId;
-    use ruma_serde::Base64;
+    use ruma_common::{api::ruma_api, serde::Base64, ServerSigningKeyId};
 
     ruma_api! {
         metadata: {
